@@ -6,16 +6,13 @@ data.table::as.data.table
 #' @export
 ggplot2::autoplot
 
-#' `hesim`: Health Economic Simulation Modeling and Decision Analysis
-#' 
 #' @description 
 #' To learn more about `hesim` visit the [website](https://hesim-dev.github.io/hesim/).
 #'
-#' @docType package
 #' @name hesim
 #' @useDynLib hesim
 #' @import data.table
 #' @importFrom Rcpp evalCpp
 #' @importFrom ggplot2 .data
 #' @keywords internal
-NULL
\ No newline at end of file
+"_PACKAGE"
\ No newline at end of file
