@@ -127,8 +127,11 @@ private:
     else if (dist_name == "weibull.quiet" || dist_name == "weibull"){
       d = new stats::weibull(1, 1);
     }
+    else if (dist_name == "weibullPH"){
+      d = new stats::weibull_ph(1, 1);
+    }
     else if (dist_name == "weibullNMA"){
-      d = new stats::weibull_nma(0, 0); // equivalent to shape = 1, scale = 1 wih weibull
+      d = new stats::weibull_nma(0, 0); // equivalent to shape = 1, scale = 1 with weibull
     }
     else if (dist_name == "gamma"){
       d = new stats::gamma(1, 1);
@@ -164,6 +167,15 @@ private:
                               params_surv.fracpoly_aux_.step_,
                               params_surv.fracpoly_aux_.random_method_);
     }
+    else if (dist_name == "pwexp"){
+      int n_times = params_surv.pwexp_aux_.time_.size();
+      std::vector<double> rate(n_times + 1, 0.0);
+      d = new stats::piecewise_exponential(rate,
+                                           params_surv.pwexp_aux_.time_);
+    }
+    else if (dist_name == "fixed"){
+      d = new stats::point_mass(1);
+    }
     else{
         Rcpp::stop("The selected distribution is not available.");
     }
@@ -231,7 +243,7 @@ public:
                               double dr = 0){
     std::vector<double> out(t.size());
     set_dist(sample, obs);
-    for (int i = 0; i < t.size(); ++i){
+    for (int i = 0; i < (int) t.size(); ++i){
       if (type == "hazard"){
         out[i] = dist_->hazard(t[i]);
       }
@@ -265,7 +277,7 @@ public:
   std::vector<double> quantile(int sample, int obs, std::vector<double> p) {
     std::vector<double> out(p.size());
     set_dist(sample, obs);
-    for (int i = 0; i < p.size(); ++i){
+    for (int i = 0; i < (int) p.size(); ++i){
       out[i] = dist_->quantile(p[i]);
     }
     return out;
