@@ -306,7 +306,8 @@ public:
  ******************************************************************************/ 
 class piecewise_exponential : public distribution {
 private: 
-  std::vector<double> rate_; ///< rate parameter at each time
+  std::vector<double> rate_; ///< rate parameter for each time period
+  std::vector<double> cumrate_; ///< cumulative rate parameter up to each time
   std::vector<double> time_; ///<A vector equal to the number of elements in rate
                              /// giving the times at which the rate changes
   
@@ -318,6 +319,10 @@ public:
   piecewise_exponential(std::vector<double> rate, std::vector<double> time){
     rate_ = rate;
     time_ = time;
+    cumrate_.resize(rate_.size());
+    cumrate_[0]=0.0;
+    for (int i=1; i < (int) rate_.size(); ++i)
+      cumrate_[i] = cumrate_[i-1]+(time_[i]-time_[i-1])*rate_[i-1];
   }
   
   void set_params(std::vector<double> params) {
@@ -329,23 +334,46 @@ public:
     return rpwexp(rate_, time_);
   }
   
+  double hazard (double x) const {
+    return rate_[find_interval(x,time_)];
+  }
+
+  double cumhazard (double x) const {
+    int i = find_interval(x, cumrate_);
+    return cumrate_[i]+rate_[i]*(x-time_[i]);
+  }
+
+  double cdf(double x) const {
+    return -expm1(-cumhazard(x));
+  }
+
+  double pdf(double x) const {
+    return hazard(x) * exp(-cumhazard(x));
+  }
+
+  double quantile(double p) const {
+    double H = -log1p(-p);
+    int i = find_interval(H, cumrate_);
+    return time_[i] + (H - cumrate_[i])/rate_[i];
+  }
+
   double trandom(double lower, double upper) const {
     if (upper != INFINITY){
       Rcpp::stop("hesim does not currently support sampling from a piecewise exponential distribution truncated from above.");
     }
     // Get index of time corresponding to lower
     int n_times = time_.size();
-    int j = 0;
-    while(lower >= time_[j] && j < n_times) {
+    unsigned int j = 0;
+    for (int i = 0; i < (n_times - 1); ++i) {
+      if (lower < time_[i + 1]) break;
       ++j;
     }
-    j = j - 1;
     
     // Simulation algorithm
     double out = 0.0;
     for (int t = j; t < n_times; ++t){
       double rexp_t = R::rexp(1/rate_[t]);
-      if (t == j){
+      if (t == (int) j){
         out = lower + rexp_t;
       } 
       else{
@@ -358,7 +386,7 @@ public:
     return out;
   }
   
-}; // end class exponential
+}; // end class piecewise_exponential
 
 /***************************************************************************//**
  * The Weibull distribution.
